exceptiontools.PartitionError
=============================

.. inheritance-diagram:: abjad.tools.exceptiontools.PartitionError.PartitionError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.PartitionError.PartitionError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
